@@ -6,21 +6,21 @@ import re
 import thermosteam as tmo
 from flexsolve import IQ_interpolation
 from .utils import copy_maybe
-from .functors.identifiers import CAS_from_any, pubchem_db
-from .functors.vapor_pressure import VaporPressure
-from .functors.phase_change import Tb, Tm, Hfus, Hsub, EnthalpyVaporization
-from .functors.critical import Tc, Pc, Vc
-from .functors.acentric import omega, StielPolar
-from .functors.triple import Tt, Pt
-from .functors.volume import Volume
-from .functors.heat_capacity import HeatCapacity
-from .functors.reaction import Hf
-from .functors.combustion import CombustionData
-from .functors.elements import compute_similarity_variable, parse_simple_formula
-from .functors.eos import GCEOS_DUMMY, PR
-from .functors.viscosity import Viscosity
-from .functors.thermal_conductivity import ThermalConductivity
-from .functors.free_energy import \
+from .properties.identifiers import CAS_from_any, pubchem_db
+from .properties.vapor_pressure import VaporPressure
+from .properties.phase_change import Tb, Tm, Hfus, Hsub, EnthalpyVaporization
+from .properties.critical import Tc, Pc, Vc
+from .properties.acentric import omega, StielPolar
+from .properties.triple import Tt, Pt
+from .properties.volume import Volume
+from .properties.heat_capacity import HeatCapacity
+from .properties.reaction import Hf
+from .properties.combustion import CombustionData
+from .properties.elements import compute_similarity_variable, parse_simple_formula
+from .properties.eos import GCEOS_DUMMY, PR
+from .properties.viscosity import Viscosity
+from .properties.thermal_conductivity import ThermalConductivity
+from .properties.free_energy import \
     EnthalpyRefSolid, EnthalpyRefLiquid, EnthalpyRefGas, \
     EntropyRefSolid, EntropyRefLiquid, EntropyRefGas, \
     ExcessEnthalpyRefSolid, ExcessEnthalpyRefLiquid, ExcessEnthalpyRefGas, \
@@ -28,10 +28,10 @@ from .functors.free_energy import \
 from .base import PhaseProperty, PhaseTProperty, PhaseTPProperty, \
                   display_asfunctor, TDependentModelHandle, TPDependentModelHandle
 from .base.units_of_measure import chemical_units_of_measure
-from .functors.dipole import dipole_moment as dipole
+from .properties.dipole import dipole_moment as dipole
 from . import functional as fn 
-from .functors.permittivity import Permittivity
-from .functors.interface import SurfaceTension
+from .properties.permittivity import Permittivity
+from .properties.interface import SurfaceTension
 from .equilibrium.unifac_data import \
     DDBST_UNIFAC_assignments, DDBST_MODIFIED_UNIFAC_assignments, DDBST_PSRK_assignments, \
     UNIFACGroupCounts, DortmundGroupCounts, PSRKGroupCounts
@@ -238,7 +238,7 @@ class Chemical:
     0.07205503890847455
     >>> # Molar volume (m^3/mol)
     >>> Water.V(phase='l', T=298.15, P=101325)
-    1.7970929501497658e-05
+    1.802828527066713e-05
     
     Note that the reference state of all chemicals is 25 degC and 1 atm:
     
@@ -283,29 +283,41 @@ class Chemical:
     >>> Water.Psat[0].show()
     TDependentModel: Wagner_McGraw
      evaluate: Wagner_McGraw(T, P=None) -> Psat [Pa]
-     Tmin: 275.00
-     Tmax: 647.35
+     Tmin: 275 K
+     Tmax: 647.35 K
 
     When called, the model handle searches through each model until it finds one with an applicable domain. If none are applicable, a value error is raised:
         
+    >>> Water.Psat(373.15)
+    101284.55179999319
     >>> # Water.Psat(1000.0) ->
-    >>> # ValueError: <TDependentModelHandle(T, P=None) -> Psat [Pa]>
-    >>> # contains no valid model at T=1000.00 K
+    >>> # ValueError: no valid model at T=1000.00 K
+    
+    Model handles as well as the models themselves have tabulation and plotting methods to help visualize how properties depend on temperature and pressure.
+    
+    >>> # Water.Psat.plot_vs_T([Water.Tm, Water.Tb], 'degC', 'atm', label="Water")
+    
+    .. figure:: ./images/Water_Psat_vs_T.png
+    
+    >>> # Plot all models
+    >>> # Water.Psat.plot_models_vs_T([Water.Tm, Water.Tb], 'degC', 'atm')
+    
+    .. figure:: ./images/Water_all_models_Psat_vs_T.png
     
     Each model may contain either a function or a functor (a function with stored data) to compute the property:
         
     >>> functor = Water.Psat[0].evaluate
     >>> functor.show()
     Functor: Wagner_McGraw(T, P=None) -> Psat [Pa]
+     Tc: 647.35 K
+     Pc: 2.2122e+07 Pa
      a: -7.7645
      b: 1.4584
      c: -2.7758
      d: -1.233
-     Tc: 647.35 K
-     Pc: 2.2122e+07 Pa
     
     .. Note::
-       All functor classes are available in the thermosteam.functors subpackage. You can also use help(<functor>) for further information on the math and equations used in the functor.
+       All chemical property functors are available in the thermosteam.properties subpackage. You can also use help(<functor>) for further information on the math and equations used in the functor.
     
     A new model can be added easily to a model handle through the `add_model` method, for example:
         
@@ -326,22 +338,6 @@ class Chemical:
     [8] Sanjari
     [9] Edalat
 
-    The `models` object is a `deque` for easier management of model order:
-    
-    >>> Water.Psat.models.rotate(-1)
-    >>> Water.Psat.show()
-    TDependentModelHandle(T, P=None) -> Psat [Pa]
-    [0] Wagner_McGraw
-    [1] Antoine
-    [2] DIPPR_EQ101
-    [3] Wagner
-    [4] Boiling_Critical_Relation
-    [5] Lee_Kesler
-    [6] Ambrose_Walton
-    [7] Sanjari
-    [8] Edalat
-    [9] User_antoine_model
-
     The `add_model` method is a high level interface that even lets you create a constant model:
         
     >>> value = Water.V.l.add_model(1.687e-05)
@@ -354,9 +350,61 @@ class Chemical:
      Tmax: inf K
      Pmin: 0 Pa
      Pmax: inf Pa
-    
+
     .. Note::
        Because no bounds were given, the model assumes it is valid across all temperatures and pressures.
+
+    Manage the model order with the `set_model_priority` and `move_up_model_priority` methods:
+    
+    >>> # Note: In this case, we pass the model name, but its
+    >>> # also possible to pass the current index, or the model itself.
+    >>> Water.Psat.move_up_model_priority('Wagner_McGraw')
+    >>> Water.Psat.show()
+    TDependentModelHandle(T, P=None) -> Psat [Pa]
+    [0] Wagner_McGraw
+    [1] Antoine
+    [2] DIPPR_EQ101
+    [3] Wagner
+    [4] Boiling_Critical_Relation
+    [5] Lee_Kesler
+    [6] Ambrose_Walton
+    [7] Sanjari
+    [8] Edalat
+    [9] User_antoine_model
+    
+    >>> Water.Psat.set_model_priority('Antoine')
+    >>> Water.Psat.show()
+    TDependentModelHandle(T, P=None) -> Psat [Pa]
+    [0] Antoine
+    [1] Wagner_McGraw
+    [2] DIPPR_EQ101
+    [3] Wagner
+    [4] Boiling_Critical_Relation
+    [5] Lee_Kesler
+    [6] Ambrose_Walton
+    [7] Sanjari
+    [8] Edalat
+    [9] User_antoine_model
+    
+    The default priority is `0` (or top priority), but you can choose any priority:
+    
+    >>> Water.Psat.set_model_priority('Antoine', 1)
+    >>> Water.Psat.show()
+    TDependentModelHandle(T, P=None) -> Psat [Pa]
+    [0] Wagner_McGraw
+    [1] Antoine
+    [2] DIPPR_EQ101
+    [3] Wagner
+    [4] Boiling_Critical_Relation
+    [5] Lee_Kesler
+    [6] Ambrose_Walton
+    [7] Sanjari
+    [8] Edalat
+    [9] User_antoine_model
+    
+    .. note::
+    
+        All models are stored as a `deque <https://docs.python.org/3.8/library/collections.html#collections.deque>`_ in the `models` attribute (e.g. Water.Psat.models).
     
     Attributes
     ----------
@@ -1240,7 +1288,7 @@ class Chemical:
         return self.ID
     
     def __repr__(self):
-        return f"Chemical('{self}')"
+        return f"<Chemical: {self}>"
     
 def lock_phase(chemical, phase):
     getfield = getattr
