@@ -114,7 +114,7 @@ class MultiStream(Stream):
     >>> key = ('l', 'Water')
     >>> s1.set_flow(1, 'gpm', key)
     >>> s1.get_flow('gpm', key)
-    0.9999999999999999
+    1.0
     >>> # Set multiple flows
     >>> key = ('l', ('Ethanol', 'Water'))
     >>> s1.set_flow([10, 20], 'kg/hr', key)
@@ -344,6 +344,15 @@ class MultiStream(Stream):
     
     ### Composition properties ###
     
+    @property
+    def vapor_fraction(self):
+        """Molar vapor fraction."""
+        if 'g' in self.phases:
+            vapor_fraction = self.imol['g'].sum() / self.F_mol
+        else:
+            vapor_fraction = 0.
+        return vapor_fraction
+    
     @property
     def V(self):
         """[float] Molar volume [m^3/mol]."""
