@@ -52,7 +52,8 @@ class Stream:
     price=0 : float
         Price per unit mass [USD/kg].
     thermo=None : Thermo
-        Thermodynamic equilibrium package. Defaults to `thermosteam.settings.get_thermo()`.
+        Thermo object to initialize input and output streams. Defaults to
+        `biosteam.settings.get_thermo()`.
     **chemical_flows : float
         ID - flow pairs.
     
@@ -84,7 +85,7 @@ class Stream:
     >>> s1.mass
     property_array([<Water: 20 kg/hr>, <Ethanol: 10 kg/hr>])
     >>> s1.vol
-    property_array([<Water: 0.019951 m^3/hr>, <Ethanol: 0.012725 m^3/hr>])
+    property_array([<Water: 0.020014 m^3/hr>, <Ethanol: 0.01344 m^3/hr>])
     
     These arrays work just like ordinary arrays, but the data is linked to the molar flows:
     
@@ -111,7 +112,7 @@ class Stream:
     >>> # Set flow
     >>> s1.set_flow(1, 'gpm', 'Water')
     >>> s1.get_flow('gpm', 'Water')
-    0.9999999999999999
+    1.0
     >>> # Set multiple flows
     >>> s1.set_flow([10, 20], 'kg/hr', ('Ethanol', 'Water'))
     >>> s1.get_flow('kg/hr', ('Ethanol', 'Water'))
@@ -145,12 +146,12 @@ class Stream:
     Other thermodynamic properties are temperature and pressure dependent as well:
     
     >>> s1.rho # Density [kg/m3]
-    916.3256776513755
+    889.2399542411935
     
     It may be more convinient to get properties with different units:
         
     >>> s1.get_property('rho', 'g/cm3')
-    0.9163256776513757
+    0.8892399542411936
     
     It is also possible to set some of the properties in different units:
         
@@ -226,6 +227,26 @@ class Stream:
         self._sink = self._source = None # For BioSTEAM
         self._init_cache()
         self._register(ID)
+
+    def isempty(self):
+        return (self._imol._data == 0.).all()
+
+    @property
+    def vapor_fraction(self):
+        """Molar vapor fraction."""
+        return 1.0 if self.phase == 'g' else 0.0
+
+    def disconnect(self):
+        sink = self._sink
+        source = self._source
+        if sink:
+            ins = sink.ins
+            index = ins.index(self)
+            ins[index] = None
+        else:
+            outs = source.outs
+            index = outs.index(self)
+            outs[index] = None
     
     def _init_indexer(self, flow, phase, chemicals, chemical_flows):
         """Initialize molar flow rates."""
@@ -459,7 +480,10 @@ class Stream:
 
     @property
     def thermal_condition(self):
-        """[ThermalCondition] Contains the temperature and pressure conditions of the stream."""
+        """
+        [ThermalCondition] Contains the temperature and pressure conditions 
+        of the stream.
+        """
         return self._TP
 
     @property
@@ -665,7 +689,7 @@ class Stream:
     @property
     def alpha(self):
         """[float] Thermal diffusivity [m^2/s]."""
-        return fn.alpha(self.kappa, self.rho, self.Cp)
+        return fn.thermal_diffusivity(self.kappa, self.rho, self.Cp)
     @property
     def rho(self):
         """[float] Density [kg/m^3]."""
@@ -700,7 +724,10 @@ class Stream:
         
         """
         others = [i for i in others if i]
-        if len(others) == 1:
+        N_others = len(others)
+        if N_others == 0:
+            self.empty()
+        elif N_others == 1:
             self.copy_like(others[0])
         else:
             assert_same_chemicals(self, others)
@@ -939,7 +966,8 @@ class Stream:
     __copy__ = copy
     
     def flow_proxy(self):
-        """Return a new stream that shares flow rate data with this one.
+        """
+        Return a new stream that shares flow rate data with this one.
         
         Examples
         --------
@@ -963,7 +991,8 @@ class Stream:
         return new
     
     def proxy(self):
-        """Return a new stream that shares all data with this one.
+        """
+        Return a new stream that shares all data with this one.
         
         Examples
         --------
@@ -1019,7 +1048,7 @@ class Stream:
 
     @property
     def vle_chemicals(self):
-        """list[Chemical] Chemicals cabable of vapor-liquid equilibrium."""
+        """list[Chemical] Chemicals cabable of liquid-liquid equilibrium."""
         chemicals = self.chemicals
         chemicals_tuple = chemicals.tuple
         indices = chemicals.get_vle_indices(self.mol != 0)
@@ -1092,7 +1121,7 @@ class Stream:
         >>> tmo.settings.set_thermo(['Water', 'Ethanol']) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, T=350, units='kg/hr')
         >>> s1.bubble_point_at_T()
-        BubblePointValues(T=350, P=76621.54388128374, IDs=('Water', 'Ethanol'), z=[0.836 0.164], y=[0.486 0.514])
+        BubblePointValues(T=350, P=76621.54388128372, IDs=('Water', 'Ethanol'), z=[0.836 0.164], y=[0.486 0.514])
         
         """
         bp = self.get_bubble_point(IDs)
@@ -1136,7 +1165,7 @@ class Stream:
         >>> tmo.settings.set_thermo(['Water', 'Ethanol']) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, T=350, units='kg/hr')
         >>> s1.dew_point_at_T()
-        DewPointValues(T=350, P=48990.56398459762, IDs=('Water', 'Ethanol'), z=[0.836 0.164], x=[0.984 0.016])
+        DewPointValues(T=350, P=48990.563984597604, IDs=('Water', 'Ethanol'), z=[0.836 0.164], x=[0.984 0.016])
         
         """
         dp = self.get_dew_point(IDs)
@@ -1304,7 +1333,7 @@ class Stream:
         >>> tmo.settings.set_thermo(['Water', 'Ethanol', 'Methanol']) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, Methanol=10, units='m3/hr')
         >>> s1.get_concentration(('Water', 'Ethanol'))
-        array([27.823,  4.265])
+        array([27.734,  4.038])
 
         """
         return self.imol[IDs]/self.F_vol
