@@ -8,17 +8,67 @@ from math import log
 from scipy.interpolate import interp1d
 from .functor import TFunctor, TPFunctor, Functor, \
                      display_asfunctor, functor_matching_params, functor_name
-from .units_of_measure import chemical_units_of_measure
+from .units_of_measure import chemical_units_of_measure, definitions, format_plot_units, convert
 from numpy import inf as infinity
 from inspect import signature
+import matplotlib.pyplot as plt
+import numpy as np
 
-__all__ = ('thermo_model', 'ThermoModel',
-           'TDependentModel', 'TPDependentModel', 
+__all__ = ('thermo_model', 'label_axis', 
+           'ThermoModel', 'TDependentModel', 'TPDependentModel', 
            'ConstantThermoModel', 'ConstantTDependentModel',
            'ConstantTPDependentModel', 'InterpolatedTDependentModel')
 
 RegisteredModels = []
 
+# %% Functions
+
+def convert_var(value, var, units):
+    if var and units:
+        var, *_ = var.split('.')
+        return convert(value, chemical_units_of_measure[var].units, units)
+    else:
+        return value
+
+def describe_parameter(var, units):
+    info = definitions.get(var) or var
+    if info:
+        var, *_ = var.split('.')
+        units = units or chemical_units_of_measure.get(var)
+        units = format_plot_units(units)
+        if units: info += f" [{units}]"
+        else: info += f" [-]"
+        return info
+
+def default_Tmax(Tmin, Tmax):
+    return Tmin + 200 if (not Tmax or Tmax is infinity) else Tmax
+
+def default_Pmax(Pmin, Pmax):
+    return 5 * Pmin if (not Pmax or Pmax is infinity) else Pmax
+
+def T_min_max(Tmin, Tmax):
+    Tmin = Tmin or 298.15
+    Tmax = default_Tmax(Tmin, Tmax)
+    return np.array([Tmin + 1e-6, Tmax - 1e-6])
+
+def P_min_max(Pmin, Pmax):
+    Pmin = Pmin or 101325
+    Pmax = default_Pmax(Pmin, Pmax)
+    return np.array([Pmin + 1e-6, Pmax - 1e-6])
+
+def T_linspace(Tmin, Tmax):
+    return np.linspace(*T_min_max(Tmin, Tmax))
+
+def P_linspace(Pmin, Pmax):
+    return np.linspace(*P_min_max(Pmin, Pmax))
+
+def label_axis(Xvar, X_units, Yvar, Y_units):
+    Xvar_description = describe_parameter(Xvar, X_units)
+    Yvar_description = describe_parameter(Yvar, Y_units)
+    plt.xlabel(Xvar_description)
+    plt.ylabel(Yvar_description)
+
+
 # %% Interfaces
 
 def thermo_model(evaluate,
@@ -50,7 +100,7 @@ def thermo_model(evaluate,
                 break
         
     assert found_model, 'no available model matching signature'
-    return Model(evaluate, Tmin, Tmax, Pmin, Pmax, name, **funcs)
+    return Model(evaluate, Tmin, Tmax, Pmin, Pmax, name, var, **funcs)
 
 
 # %% Thermo models
@@ -68,7 +118,8 @@ class ThermoModel:
     def __init__(self, evaluate,
                  Tmin=None, Tmax=None,
                  Pmin=None, Pmax=None,
-                 name=None, **funcs):
+                 name=None, var=None, **funcs):
+        self.var = var or (evaluate.var if hasattr(evaluate, 'var') else "")
         self.name = name or functor_name(evaluate)
         self.evaluate = evaluate
         self.__dict__.update(funcs)
@@ -77,16 +128,47 @@ class ThermoModel:
         if Tmin: self.Tmin = Tmin
         if Tmax: self.Tmax = Tmax
     
+    def plot_vs_T(self, T_range=None, T_units=None, units=None, P=101325,
+                  label_axis=True, **plot_kwargs):
+        Ts, Ys = self.tabulate_vs_T(T_range, T_units, units, P)
+        plot_kwargs['label'] = plot_kwargs.get('label') or self.name.replace('_', " ")
+        plt.plot(Ts, Ys, **plot_kwargs)
+        if label_axis: label_axis('T', T_units, self.var, units)
+        
+    
+    def plot_vs_P(self, P_range=None, P_units=None, units=None, T=298.15, 
+                  label_axis=True, **plot_kwargs):
+        Ps, Ys = self.tabulate_vs_P(P_range, P_units, units, T)
+        plot_kwargs['label'] = plot_kwargs.get('label') or self.name.replace('_', " ")
+        plt.plot(Ps, Ys, **plot_kwargs)
+        if label_axis: label_axis('P', P_units, self.var, units)
+    
+    @property
+    def __call__(self):
+        return self.evaluate
+    
     def __repr__(self):
         return f"<{type(self).__name__}: {self.name}>"
 
 
 class TDependentModel(ThermoModel, Functor=TFunctor):
     
-    @property
-    def var(self):
-        try: return self.evaluate.var
-        except: return None
+    def tabulate_vs_T(self, T_range=None, T_units=None, units=None, P=101325):
+        if not T_range: T_range = (self.Tmin, self.Tmax)
+        Ts = T_linspace(*T_range)
+        Ys = np.array([self(T) for T in Ts])
+        if T_units: Ts = convert_var(Ts, 'T', T_units)
+        if units: Ys = convert_var(Ys, self.var, units)
+        return Ts, Ys
+    
+    def tabulate_vs_P(self, P_range=None, P_units=None, units=None, T=298.15):
+        if not P_range: P_range = (self.Pmin, self.Pmax)
+        Ps = P_min_max(*P_range)
+        Y = self(T)
+        Ys = np.array([Y, Y])
+        if P_units: Ps = convert_var(Ps, 'P', P_units)
+        if units: Ys = convert_var(Ys, self.var, units)
+        return Ps, Ys
     
     def indomain(self, T, P=None):
         return self.IGNORE_DOMAIN or self.Tmin < T < self.Tmax
@@ -109,15 +191,29 @@ class TDependentModel(ThermoModel, Functor=TFunctor):
     def show(self):
         print(f"{type(self).__name__}: {self.name}\n"
               f" evaluate: {display_asfunctor(self.evaluate)}\n"
-              f" Tmin: {self.Tmin:.2f}\n"
-              f" Tmax: {self.Tmax:.2f}")
+              f" Tmin: {self.Tmin:.5g} K\n"
+              f" Tmax: {self.Tmax:.5g} K")
         
     _ipython_display_ =  show
 
 
 class TPDependentModel(ThermoModel, Functor=TPFunctor):
     
-    var = TDependentModel.var
+    def tabulate_vs_T(self, T_range=None, T_units=None, units=None, P=101325):
+        if not T_range: T_range = (self.Tmin, self.Tmax)
+        Ts = T_linspace(*T_range)
+        Ys = np.array([self(T, P) for T in Ts])
+        if T_units: Ts = convert_var(Ts, 'T', T_units)
+        if units: Ys = convert_var(Ys, self.var, units)
+        return Ts, Ys
+    
+    def tabulate_vs_P(self, P_range=None, P_units=None, units=None, T=298.15):
+        if not P_range: P_range = (self.Pmin, self.Pmax)
+        Ps = P_linspace(*P_range)
+        Ys = np.array([self(T, P) for P in Ps])
+        if P_units: Ps = convert_var(Ps, 'P', P_units)
+        if units: Ys = convert_var(Ys, self.var, units)
+        return Ps, Ys
     
     def indomain(self, T, P):
         return self.IGNORE_DOMAIN or (self.Tmin < T < self.Tmax
@@ -162,6 +258,22 @@ class ConstantThermoModel(ThermoModel):
         if Pmax: self.Pmax = Pmax
         if Tmin: self.Tmin = Tmin
         if Tmax: self.Tmax = Tmax
+
+    def tabulate_vs_T(self, T_range=None, T_units=None, units=None, P=101325):
+        if not T_range: T_range = (self.Tmin, self.Tmax)
+        Ts = T_min_max(self.Tmin, self.Tmax)
+        Ys = np.array([self.value, self.value])
+        if T_units: Ts = convert_var(Ts, 'T', T_units)
+        if units: Ys = convert_var(Ys, self.var, units)
+        return Ts, Ys
+    
+    def tabulate_vs_P(self, P_range=None, P_units=None, units=None, T=298.15):
+        if not P_range: P_range = (self.Pmin, self.Pmax)
+        Ps = P_min_max(*P_range)
+        Ys = np.array([self.value, self.value])
+        if P_units: Ps = convert_var(Ps, 'P', P_units)
+        if units: Ys = convert_var(Ys, self.var, units)
+        return Ps, Ys
     
     def indomain(self, T=None, P=None):
         return True
@@ -185,12 +297,15 @@ class ConstantThermoModel(ThermoModel):
         return 0
 
     def show(self):
-        var = self.var
-        if var in chemical_units_of_measure:
-            units = " " + chemical_units_of_measure[var]
+        if self.var :
+            var = f' ({self.var})'
+            var_no_phase, *_ = self.var.split('.')
+            if var_no_phase in chemical_units_of_measure:
+                units = " " + str(chemical_units_of_measure[var_no_phase])
+            else:
+                units = ""
         else:
-            units = ""
-        var = f' ({self.var})' if self.var else ""
+            var = units = ""
         print(f"{type(self).__name__}: {self.name}\n"
               f" value{var}: {self.value}{units}\n"
               f" Tmin: {self.Tmin:.5g} K\n"
@@ -227,6 +342,8 @@ class InterpolatedTDependentModel(ThermoModel):
     def evaluate(self, T, P=None):
         return self.spline(T) if (self.T_lb <= T <= self.T_ub) else self.extrapolator(T)
     
+    tabulate_vs_T = TDependentModel.tabulate_vs_T
+    tabulate_vs_P = TDependentModel.tabulate_vs_P
     indomain = TDependentModel.indomain
     integrate_by_T = TDependentModel.integrate_by_T
     integrate_by_T_over_T = TDependentModel.integrate_by_T_over_T
