@@ -4,8 +4,14 @@ Created on Mon Sep 30 23:02:53 2019
 
 @author: yoelr
 """
+import matplotlib.pyplot as plt
 from collections import deque
-from .thermo_model import ThermoModel, ConstantThermoModel, thermo_model
+from numpy import inf as infinity
+from .thermo_model import (ThermoModel,
+                           TDependentModel,
+                           TPDependentModel,
+                           thermo_model,
+                           label_axis as create_axis_labels)
 from .functor import functor_lookalike
 
 __all__ = ('ThermoModelHandle',
@@ -13,18 +19,16 @@ __all__ = ('ThermoModelHandle',
            'TPDependentModelHandle')
 
 # %% Utilities
-
-def get_not_a(obj, cls):
-    isa = isinstance
-    if isa(obj, cls):
-        return None
-    elif hasattr(obj, '__iter__'):
-        for i in obj:
-            if not isa(i, cls):
-                return i
-    else:
-        return obj
     
+def find_model_by_name(models, name):
+    for model in models:
+        if model.name == name: return model
+    raise LookupError(f'no model with name {name}')
+    
+def find_model_index_by_name(models, name):
+    for index, model in enumerate(models):
+        if model.name == name: return index
+    raise LookupError(f'no model with name {name}')
 
 # %% Handles
 
@@ -32,6 +36,33 @@ def get_not_a(obj, cls):
 class ThermoModelHandle:
     __slots__ = ('models',)
     
+    def plot_vs_T(self, T_range=None, T_units=None, units=None, 
+                  P=101325, label_axis=True, **plot_kwargs):
+        Ts, Ys = self.tabulate_vs_T(T_range, T_units, units, P)
+        plt.plot(Ts, Ys, **plot_kwargs)
+        if label_axis: create_axis_labels('T', T_units, self.var, units)
+        plt.legend()
+        
+    
+    def plot_vs_P(self, P_range=None, P_units=None, units=None,
+                  T=298.15, label_axis=True, **plot_kwargs):
+        Ps, Ys = self.tabulate_vs_P(P_range, P_units, units, T)
+        plt.plot(Ps, Ys, **plot_kwargs)
+        if label_axis: create_axis_labels('P', P_units, self.var, units)
+        plt.legend()
+    
+    def plot_models_vs_T(self, T_range=None, T_units=None, units=None,
+                         P=101325, label_axis=True, **plot_kwargs):
+        for model in self: model.plot_vs_T(T_range, T_units, units, P, False, **plot_kwargs)
+        if label_axis: create_axis_labels('T', T_units, self.var, units)
+        plt.legend()
+    
+    def plot_models_vs_P(self, P_range=None, P_units=None, units=None,
+                         T=298.15, label_axis=True, **plot_kwargs):
+        for model in self: model.plot_vs_P(P_range, P_units, units, T, False, **plot_kwargs)
+        if label_axis: create_axis_labels('P', P_units, self.var, units)
+        plt.legend()
+    
     @property
     def var(self):
         for i in self.models:
@@ -45,10 +76,9 @@ class ThermoModelHandle:
         return self.models[index]
     
     def __setitem__(self, index, model):
-        not_a_model = get_not_a(model, ThermoModel)
-        assert not_a_model is None, ("a 'ThermoModelHandle' object may only "
-                                     "contain 'ThermoModel' objects, not "
-                                    f"'{type(not_a_model).__name__}' objects")
+        assert isinstance(model, ThermoModel), (
+            "a 'ThermoModelHandle' object may only "
+            "contain 'ThermoModel' objects")
         self.models[index] = model
 	
     def __iter__(self):
@@ -61,6 +91,40 @@ class ThermoModelHandle:
         return self.__class__(self.models.copy())
     __copy__ = copy
     
+    def set_model_priority(self, model, priority=0):
+        models = self.models
+        isa = isinstance
+        if isa(model, int):
+            index = model
+            model = models[index]
+        elif isa(model, str):
+            name = model
+            model = find_model_by_name(models, name)
+        elif isa(model, ThermoModel):
+            pass
+        else:
+            raise ValueError(
+                '`model` must be either the index [int], name [str], '
+                'or the model itself [ThermoModel]')
+        models.remove(model)
+        models.insert(priority, model)
+    
+    def move_up_model_priority(self, model, priority=0):
+        models = self.models
+        isa = isinstance
+        if isa(model, int):
+            index = model
+        elif isa(model, str):
+            name = model
+            index = find_model_index_by_name(models, name)
+        elif isa(model, ThermoModel):
+            index = models.index(model)
+        else:
+            raise ValueError(
+                '`model` must be either the index [int], name [str], '
+                'or the model itself [ThermoModel]')
+        models.rotate(priority - index)
+    
     def add_model(self, evaluate=None,
                   Tmin=None, Tmax=None,
                   Pmin=None, Pmax=None,
@@ -85,24 +149,23 @@ class ThermoModelHandle:
         return evaluate
        
     def show(self):
+        info = f"{self}\n"
         if self.models:
             models = ("\n").join([f'[{i}] {model.name}'
                                   for i, model in enumerate(self.models)])
         else:
             models = "(no models available)"
-        print(f"{self}\n"
-              f"{models}")
+        print(info + models)
         
     _ipython_display_ = show
 
     
 class TDependentModelHandle(ThermoModelHandle):
     __slots__ = ()
-    
-    def lock_TP(self, T, P=None):
-        models = self.models
-        constant_model = ConstantThermoModel(self(T))
-        models.appendleft(constant_model)
+    Pmin = 0
+    Pmax = infinity
+    tabulate_vs_T = TDependentModel.tabulate_vs_T
+    tabulate_vs_P = TDependentModel.tabulate_vs_P
         
     @property
     def Tmin(self):
@@ -114,14 +177,12 @@ class TDependentModelHandle(ThermoModelHandle):
     def __call__(self, T, P=None):
         for model in self.models:
             if model.indomain(T): return model.evaluate(T)
-        # return model.evaluate(T)
-        raise ValueError(f"{repr(self)} contains no valid model at T={T:.2f} K")
-            
+        raise ValueError(f"no valid model at T={T:.2f} K")
+        
     def differentiate_by_T(self, T, P=None, dT=1e-12):
         for model in self.models:
             if model.indomain(T): return model.differentiate_by_T(T, dT=dT)
-        # return model.differentiate_by_T(T) 
-        raise ValueError(f"{repr(self)} contains no valid model at T={T:.2f} K")
+        raise ValueError(f"no valid model at T={T:.2f} K")
         
     def differentiate_by_P(self, T, P=None, dP=1e-12):
         return 0
@@ -148,8 +209,7 @@ class TDependentModelHandle(ThermoModelHandle):
             elif ub_satisfied and Tmin < Tb:
                 integral += model.integrate_by_T(Tmin, Tb)
                 Tb = Tmin
-        # return integral + model.integrate_by_T(Ta, Tb)
-        raise ValueError(f"{repr(self)} contains no valid model between T={Ta:.2f} to {Tb:.2f} K")
+        raise ValueError(f"no valid model between T={Ta:.2f} to {Tb:.2f} K")
     
     def integrate_by_P(self, Pa, Pb, T):
         return (Pb - Pa) * self(T)
@@ -172,8 +232,7 @@ class TDependentModelHandle(ThermoModelHandle):
             elif ub_satisfied and Tmin < Tb:
                 integral += model.integrate_by_T_over_T(Tmin, Tb)
                 Tb = Tmin
-        # return integral + model.integrate_by_T_over_T(Ta, Tb)
-        raise ValueError(f"{repr(self)} contains no valid model between T={Ta:.2f} to {Tb:.2f} K")
+        raise ValueError(f"no valid model between T={Ta:.2f} to {Tb:.2f} K")
     
     
 class TPDependentModelHandle(ThermoModelHandle):
@@ -182,10 +241,8 @@ class TPDependentModelHandle(ThermoModelHandle):
     Tmin = TDependentModelHandle.Tmin
     Tmax = TDependentModelHandle.Tmax
     
-    def lock_TP(self, T, P):
-        models = self.models
-        constant_model = ConstantThermoModel(self(T, P))
-        models.appendleft(constant_model)
+    tabulate_vs_T = TPDependentModel.tabulate_vs_T
+    tabulate_vs_P = TPDependentModel.tabulate_vs_P
     
     @property
     def Pmin(self):
@@ -197,20 +254,17 @@ class TPDependentModelHandle(ThermoModelHandle):
     def __call__(self, T, P):
         for model in self.models:
             if model.indomain(T, P): return model.evaluate(T, P)
-        # return model.evaluate(T, P)
-        raise ValueError(f"{repr(self)} contains no valid model at T={T:.2f} K and P={P:5g} Pa")
+        raise ValueError(f"no valid model at T={T:.2f} K and P={P:5g} Pa")
 
     def differentiate_by_T(self, T, P):
         for model in self.models:
             if model.indomain(T, P): return model.differentiate_by_T(T, P)
-        # return model.differentiate_by_T(T, P) 
-        raise ValueError(f"{repr(self)} contains no valid model at T={T:.2f} K and P={P:5g} Pa")
+        raise ValueError(f"no valid model at T={T:.2f} K and P={P:5g} Pa")
             
     def differentiate_by_P(self, T, P):
         for model in self.models:
              if model.indomain(T, P): return model.differentiate_by_P(T, P)
-        # return model.differentiate_by_P(T, P) 
-        raise ValueError(f"{repr(self)} contains no valid model at T={T:.2f} K and P={P:5g} Pa")
+        raise ValueError(f"no valid model at T={T:.2f} K and P={P:5g} Pa")
 
     def integrate_by_T(self, Ta, Tb, P):
         integral = 0
@@ -230,8 +284,7 @@ class TPDependentModelHandle(ThermoModelHandle):
             elif ub_satisfied and Tmin < Tb:
                 integral += model.integrate_by_T(Tmin, Tb, P)
                 Tb = Tmin
-        # return integral + model.integrate_by_T(Ta, Tb, P) 
-        raise ValueError(f"{repr(self)} contains no valid model between T={Ta:.2f} to {Tb:.2f} K at P={P:5g} Pa")
+        raise ValueError(f"no valid model between T={Ta:.2f} to {Tb:.2f} K at P={P:5g} Pa")
     
     def integrate_by_P(self, Pa, Pb, T):
         integral = 0
@@ -252,8 +305,7 @@ class TPDependentModelHandle(ThermoModelHandle):
             elif ub_satisfied and Pmin < Pb:
                 integral += model.integrate_by_P(Pmin, Pb, T)
                 Pb = Pmin
-        # return integral + model.integrate_by_P(Pa, Pb, T) 
-        raise ValueError(f"{repr(self)} contains no valid model between P={Pa:5g} to {Pb:5g} Pa ast T={T:.2f}")
+        raise ValueError(f"no valid model between P={Pa:5g} to {Pb:5g} Pa ast T={T:.2f}")
     
     def integrate_by_T_over_T(self, Ta, Tb, P):
         integral = 0
@@ -274,8 +326,7 @@ class TPDependentModelHandle(ThermoModelHandle):
             elif ub_satisfied and Tmin < Tb:
                 integral += model.integrate_by_T_over_T(Tmin, Tb, P)
                 Tb = Tmin
-        # return integral + model.integrate_by_T_over_T(Ta, Tb, P) 
-        raise ValueError(f"{repr(self)} contains no valid model between T={Ta:.2f} to {Tb:.2f} K")
+        raise ValueError(f"no valid model between T={Ta:.2f} to {Tb:.2f} K")
         
             
     
\ No newline at end of file
