@@ -4,8 +4,7 @@ Created on Wed Nov 27 19:11:28 2019
 
 @author: yoelr
 """
-from fluids import core as fluids_core
-from fluids.core import *
+from fluids.core import thermal_diffusivity
 from cmath import sqrt as csqrt
 from numba import njit
 from .base import functor
@@ -15,14 +14,13 @@ import numpy as np
 __all__ = ('isobaric_expansion', 'isothermal_compressibility', 
            'Cp_minus_Cv', 'speed_of_sound', 'Joule_Thomson',
            'phase_identification_parameter', 'phase_identification_parameter_phase',
-           'isentropic_exponent', 'rho_to_V', 'rho', 'V_to_rho', 'mu_to_nu', 
-           'nu', 'Z', 'B_to_Z', 'Z_to_B', 'Z_from_virial_density_form', 
+           'isentropic_exponent', 'rho_to_V', 'V_to_rho', 'mu_to_nu', 
+           'Z', 'B_to_Z', 'Z_to_B', 'Z_from_virial_density_form', 
            'Z_from_virial_pressure_form', 'zs_to_ws', 'ws_to_zs', 'zs_to_Vfs', 
            'Vfs_to_zs', 'none_and_length_check', 'normalize', 'mixing_simple', 
            'mixing_logarithmic', 'Parachor', 'SG_to_API', 'API_to_SG', 'SG',
-           'horner', 'allclose_variable', 'polylog2', 'horner',
-           ) + tuple(fluids_core.__all__)
-            
+           'horner', 'allclose_variable', 'polylog2', 'horner', 'thermal_diffusivity'
+)
 
 @functor
 def horner_polynomial(T, coeffs):
@@ -36,7 +34,8 @@ def Pr(Cp, mu, k):
     return Cp * mu / k
 
 def mu_to_nu(mu, rho):
-    r'''Return the kinematic viscosity (nu) given the dynamic viscosity (mu) and 
+    r'''
+    Return the kinematic viscosity (nu) given the dynamic viscosity (mu) and 
     density (rho).
 
     .. math::
@@ -44,7 +43,7 @@ def mu_to_nu(mu, rho):
 
     Examples
     --------
-    >>> nu(0.000998, 998.)
+    >>> mu_to_nu(0.000998, 998.)
     1.0e-06
 
     References
@@ -53,14 +52,14 @@ def mu_to_nu(mu, rho):
        Applications. Boston: McGraw Hill Higher Education, 2006.
     '''
     return mu/rho
-nu = mu_to_nu
 
 def V_to_rho(V, MW):
-    r'''Return the density (rho) in kg/m^3 given the molar volume (V) in
+    r'''
+    Return the density (rho) in kg/m^3 given the molar volume (V) in
     m^3/mol and molecular weight (MW) in g/mol.
 
     .. math::
-        \rho = \frac{MW}{1000\cdot VM}
+        \rho = \frac{MW}{1000\cdot V}
     
     Parameters
     ----------
@@ -81,10 +80,10 @@ def V_to_rho(V, MW):
 
     '''
     return MW/V/1000.
-rho = V_to_rho
 
 def rho_to_V(rho, MW):
-    r'''Return the molar volume (V) in m^3/mol given the density (rho) in
+    r'''
+    Return the molar volume (V) in m^3/mol given the density (rho) in
     kg/m^3 and molecular weight (MW) in g/mol.
 
     .. math::
@@ -111,7 +110,8 @@ def rho_to_V(rho, MW):
     return MW/rho/1000.
 
 def SG_to_API(SG):
-    r'''Calculates specific gravity of a liquid given its API, as shown in
+    r'''
+    Return specific gravity of a liquid given its API, as shown in
     [1]_.
 
     .. math::
