@@ -14,7 +14,7 @@ from . import cache
 from . import assert_utils
 from . import var_utils
 from . import registry
-from . import math_display
+from . import colors
 
 __all__ = (*pickle_utils.__all__,
            *repr_utils.__all__,
@@ -25,7 +25,7 @@ __all__ = (*pickle_utils.__all__,
            *assert_utils.__all__,
            *var_utils.__all__,
            *registry.__all__,
-           *math_display.__all__)
+           *colors.__all__)
 
 from .pickle_utils import *
 from .repr_utils import *
@@ -36,4 +36,4 @@ from .cache import *
 from .assert_utils import *
 from .var_utils import *
 from .registry import *
-from .math_display import *
\ No newline at end of file
+from .colors import *
\ No newline at end of file
